Crate aperture_lens

Crate aperture_lens 

Modules

bindings
This module contains abigen! generated bindings for solidity contracts. This is autogenerated code. Do not manually edit these files. These files may be overwritten by the codegen system at any time.
caller
pool_lens
position_lens
prelude
storage_lens

Macros

call_ephemeral_contract
Call an ephemeral contract and return the decoded data